==> screen_text_extractor-0.0.1.tar.gz: README.md <==
# screen_text_extractor

[![pub version][pub-image]][pub-url]

[pub-image]: https://img.shields.io/pub/v/screen_text_extractor.svg
[pub-url]: https://pub.dev/packages/screen_text_extractor

This plugin allows Flutter **desktop** apps to extract text from screen.

[![Discord](https://img.shields.io/badge/discord-%237289DA.svg?style=for-the-badge&logo=discord&logoColor=white)](https://discord.gg/vba8W9SF)

---

<!-- START doctoc generated TOC please keep comment here to allow auto update -->
<!-- DON'T EDIT THIS SECTION, INSTEAD RE-RUN doctoc TO UPDATE -->

- [screen_text_extractor](#screen_text_extractor)
  - [Platform Support](#platform-support)
  - [Quick Start](#quick-start)
    - [Installation](#installation)
    - [Usage](#usage)
  - [API](#api)
    - [ScreenTextExtractor](#screentextextractor)
  - [License](#license)

<!-- END doctoc generated TOC please keep comment here to allow auto update -->

## Platform Support

| MacOS | Linux | Windows |
| :---: | :---: | :-----: |
|   ✔️   |   ✔️   |    ✔️    |

## Quick Start

### Installation

Add this to your package's pubspec.yaml file:

```yaml
dependencies:
  screen_text_extractor: ^0.0.1
```

Or

```yaml
dependencies:
  screen_text_extractor:
    git:
      url: https://github.com/leanflutter/screen_text_extractor.git
      ref: main
```

### Usage

```dart
import 'package:screen_text_extractor/screen_text_extractor.dart';

ExtractedData data;

data = await ScreenTextExtractor.instance.extractFromClipboard();
data = await ScreenTextExtractor.instance.extractFromScreenCapture();
data = await ScreenTextExtractor.instance.extractFromScreenSelection();
```

> Please see the example app of this plugin for a full example.

## API

### ScreenTextExtractor

| Method                         | Description  | Linux | MacOS | Windows |
| ------------------------------ | ------------ | ----- | ----- | ------- |
| isAllowedScreenCaptureAccess   | `macOS` only | ➖     | ✔️     | ➖       |
| requestScreenCaptureAccess     | `macOS` only | ➖     | ✔️     | ➖       |
| isAllowedScreenSelectionAccess | `macOS` only | ➖     | ✔️     | ➖       |
| requestScreenSelectionAccess   | `macOS` only | ➖     | ✔️     | ➖       |
| extractFromClipboard           |              | ✔️     | ✔️     | ✔️       |
| extractFromScreenCapture       |              | ✔️     | ✔️     | ✔️       |
| extractFromScreenSelection     |              | ✔️     | ✔️     | ✔️       |

## License

```text
MIT License

Copyright (c) 2021 LiJianying <lijy91@foxmail.com>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
```

==> screen_text_extractor-0.1.0.tar.gz: README.md <==
# screen_text_extractor

[![pub version][pub-image]][pub-url]

[pub-image]: https://img.shields.io/pub/v/screen_text_extractor.svg
[pub-url]: https://pub.dev/packages/screen_text_extractor

This plugin allows Flutter **desktop** apps to extract text from screen.

[![Discord](https://img.shields.io/badge/discord-%237289DA.svg?style=for-the-badge&logo=discord&logoColor=white)](https://discord.gg/zPa6EZ2jqb)

---

<!-- START doctoc generated TOC please keep comment here to allow auto update -->
<!-- DON'T EDIT THIS SECTION, INSTEAD RE-RUN doctoc TO UPDATE -->

- [screen_text_extractor](#screen_text_extractor)
  - [Platform Support](#platform-support)
  - [Quick Start](#quick-start)
    - [Installation](#installation)
    - [Usage](#usage)
  - [API](#api)
    - [ScreenTextExtractor](#screentextextractor)
  - [License](#license)

<!-- END doctoc generated TOC please keep comment here to allow auto update -->

## Platform Support

| MacOS | Linux | Windows |
| :---: | :---: | :-----: |
|   ✔️   |   ✔️   |    ✔️    |

## Quick Start

### Installation

Add this to your package's pubspec.yaml file:

```yaml
dependencies:
  screen_text_extractor: ^0.1.0
```

Or

```yaml
dependencies:
  screen_text_extractor:
    git:
      url: https://github.com/leanflutter/screen_text_extractor.git
      ref: main
```

### Usage

```dart
import 'package:screen_text_extractor/screen_text_extractor.dart';

ExtractedData data;

data = await ScreenTextExtractor.instance.extractFromClipboard();
data = await ScreenTextExtractor.instance.extractFromScreenCapture();
data = await ScreenTextExtractor.instance.extractFromScreenSelection();
```

> Please see the example app of this plugin for a full example.

## API

### ScreenTextExtractor

| Method                         | Description  | Linux | MacOS | Windows |
| ------------------------------ | ------------ | ----- | ----- | ------- |
| isAllowedScreenCaptureAccess   | `macOS` only | ➖     | ✔️     | ➖       |
| requestScreenCaptureAccess     | `macOS` only | ➖     | ✔️     | ➖       |
| isAllowedScreenSelectionAccess | `macOS` only | ➖     | ✔️     | ➖       |
| requestScreenSelectionAccess   | `macOS` only | ➖     | ✔️     | ➖       |
| extractFromClipboard           |              | ✔️     | ✔️     | ✔️       |
| extractFromScreenCapture       |              | ✔️     | ✔️     | ✔️       |
| extractFromScreenSelection     |              | ✔️     | ✔️     | ✔️       |

## License

```text
MIT License

Copyright (c) 2021 LiJianying <lijy91@foxmail.com>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
```
